- Data
A character string giving the path of the input file,
or a matrix with 5 (7) columns for daily (sub-daily) data: variable code, year,
month, day, (hour), (minute), value.
- meta
A character vector with 6 elements: station ID, latitude, longitude,
altitude, variable code, units. If Data is a path, meta is
ignored.
- outpath
Character string giving the path for the QC results.
- IQR
Interquantile range used to define outliers. By default it is 5 for
precipitation, 3 for air temperature, and 4 for any other variable.
- bplot
If TRUE, create a boxplot and print it into a PDF.
- outfile
Filename for the plot. Ignored if bplot is FALSE.
- ...
Graphical parameters passed to the function boxplot.