Report occurrences of equal consecutive values in daily data.
Usage
daily_repetition(dailydata, meta = NULL, outpath, n = 4)
Arguments
dailydata
A character string giving the path of the input file,
or a 5-column matrix with following columns: variable code, year, month,
day, and the daily value.
meta
A character vector with 6 elements: station ID, latitude, longitude,
altitude, variable code, units. If dailydata is a path, meta is
ignored.
outpath
Character string giving the path for the QC results.
n
Number of minimum equal consecutive values required for a flag. The
default is 4.
Author
Alba Gilabert, Yuri Brugnara
Details
The input file must follow the Copernicus Station Exchange Format (SEF).
Zeroes are automatically excluded in bounded variables such as precipitation.