Learn R Programming

dataresqc (version 1.1.1)

duplicate_times: Duplicate times test

Description

Flag times that appear more than once.

Usage

duplicate_times(subdailydata, meta = NULL, outpath)

Arguments

subdailydata

A character string giving the path of the input file, or a 7-column matrix with following columns: variable code, year, month, day, hour, minute, value.

meta

A character vector with 6 elements: station ID, latitude, longitude, altitude, variable code, units. If subdailydata is a path, meta is ignored.

outpath

Character string giving the path for the QC results.

Author

Alba Gilabert, Yuri Brugnara

Details

The input file must follow the Copernicus Station Exchange Format (SEF).

Examples

Run this code
duplicate_times(Bern$p, Meta$p[which(Meta$p$id=="Bern"),], outpath = tempdir())

Run the code above in your browser using DataLab