Report occurrences of equal consecutive values in subdaily data.
Usage
subdaily_repetition(subdailydata = file.choose(), meta = NULL, outpath, n = 6)
Arguments
subdailydata
A character string giving the path of the input file,
or a 7-column matrix with following columns: variable code, year, month,
day, hour, minute, value.
meta
A character vector with 6 elements: station ID, latitude, longitude,
altitude, variable code, units. If subdailydata is a path, meta is
ignored.
outpath
Character string giving the path for the QC results.
n
Number of minimum equal consecutive values required for a flag. The
default is 6.
Author
Alba Gilabert, Yuri Brugnara
Details
The input file must follow the Copernicus Station Exchange Format (SEF).
Zeroes are automatically excluded in bounded variables such as precipitation.