climexp_to_sef: Download a GHCN-Daily data file from the Climate Explorer and convert it
into the Station Exchange Format
Description
Download a GHCN-Daily data file from the Climate Explorer and convert it
into the Station Exchange Format
Usage
climexp_to_sef(url, outpath)
Arguments
- url
Character string giving the url of the data file.
- outpath
Character string giving the path where to save the file.